require_relative 'player'
require_relative 'die'
require_relative 'game_turn'
require_relative 'treasure_trove'

module StudioGame
  class Game
    def initialize(title)
      @title = title.capitalize
      @players = []
    end

    def add_player(player)
      @players.push(player)
    end

    def pop_players
      @players.pop
    end

    def print_final(player)
      puts "#{player.name}: #{player.health}"
    end
    def print_stats
      puts
      puts "#{@title} Statistics:"
      puts
      @strong_players = @players.select { |playa| playa.strong? }
      @wimpy_players = @players.reject { |playa| playa.strong? }

      puts "#{@strong_players.size} strong players:"
      @strong_players.each do |playa|
        print_final(playa)
      end
      puts
      puts "#{@wimpy_players.size} weak players:"
      @wimpy_players.each do |playa|
        print_final(playa)
      end
      puts
      puts "#{@title} Point Totals:"
      @players.sort!
      @players.each do |playa|
        puts "#{playa.name.ljust(15, '.')} #{playa.points}"
        playa.each_found_treasure do |treasure|
          puts "#{treasure.name} .... #{treasure.points}"
        end
        puts
      end
    end

    attr_reader :title

    def play(rounds)
      puts "Welcome to #{@title}!"
      puts "There are 6 treasures to be found:"
      treasures = TreasureTrove::TREASURES
      treasures.each do |treasure|
        puts "A #{treasure.name} is worth #{treasure.points} points!"
      end
      puts "There are #{@players.size} players in #{@title}. We will play #{rounds} rounds:"
      puts
      @players.each do |player|
        puts player
      end
      1.upto(rounds) do |round|
        puts
        puts "----ROUND #{round} ------"
        @players.each do |player|
          GameTurn.take_turn(player)
          puts player
        end
      end
      print_stats
    end

    def load_players(from_file)
      File.readlines(from_file).each do |line|
        name, health = line.split(',')
        yungplayer = Player.new(name,health.to_i)
        add_player(yungplayer)
      end
    end

    def save_high_scores(to_file="high_scores.txt")
      File.open(to_file, "w") do |file|
        file.puts "#{@title} high scores:"
        @players.sort!
        @players.each do |playa|
          file.puts "#{playa.name.ljust(15, '.')} #{playa.points}"
        end
      end
    end

    #attr_reader :players
  end
end
